local checker = require "statusChecker"

local _M = {}

--The P1 device IO/LEDs control parameters
_G.IOLED_OPTIONS = 
{
	WITH_FPGA = true,	--With FPGA
	FPGA_DEV_ADDR = 0xf4,	--FPGA I2C device address
	WITH_FPGA_LEDS	= false,	--With FPGA LEDs
	------
	RESET_PIN = 9,	--GPIO9 as RESET button
	------
	GPIO_LEDS = {
		["stream"] = 58,	--GPIO streaming(cloud) LED
		["signal"] = 57,	--GPIO hdmi(signal) LED
		["wifi"] = 76
	},
	------
	FPGA_LEDS = {
	},
	------
	--Rolling options: When pressed (but no arrived reset time) RESET button, rolling LEDs
	ROLLING_SEQ = { "signal", "stream" },
	
	ROLLING_LANG_STATUS = {
		[0x01] = "RED:ON",		--Default language is CN
		[0x04] = "GREEN:ON",	--Default language is EN
		[0x00] = "YELLOW:ON"	--Other languages
	},
	
	ROLLING_MIN_NUMS = 1,	--How many leds at least show when rolling (Multiple languages support should +1)
	------
	
	ACTION_STATUS = {
		["default"] = {
			["signal"] = "OFF",
			["wifi"] = "OFF",
			["stream"] = "OFF",
		},
	
		["restore"] = {
			["signal"] = "BLINK",
			["wifi"] = "BLINK",
			["stream"] = "BLINK",
		},
	
		["reboot"] = {
			["signal"] = "BLINK",
			["wifi"] = "BLINK",
			["stream"] = "BLINK",
		},
		
		["reset"] = {
			["signal"] = "BLINK",
			["wifi"] = "BLINK",
			["stream"] = "BLINK",
		}
	},
	
	RESET_HOLD = 5000	--Hold RESET button more than this value(milliseconds), should do restore factory action!
}

local ctrl_module = nil

function _M.Check(period_ms)
	if not ctrl_module then
		ctrl_module = require( "controlModule" )
	end
	
	if not ctrl_module then
		return
	end
	
	if not checker then
		return
	end
	
	--Signal checking
	local signal = checker.CheckSignal()
	if signal then
		ctrl_module.LedControl( "signal", "ON" )
	else
		ctrl_module.LedControl( "signal", "OFF" )
	end
	
	if ctrl_module.userControl then return end

	--Wifi checking
	local wifiName, workMode, status = checker.CheckWifiStatus()
	if not wifiName then
		ctrl_module.LedControl( "wifi", "OFF" )
	else
		if workMode == "STATION" then
			local ledStatus = "OFF"
			if status == "CONNECTING" then
				ledStatus = "BLINK"
			elseif status == "CONNECTED" or status == "INTERNET_OK" then
				ledStatus = "ON"
			elseif status == "ERROR" then
				ledStatus = "BLINK-FAST"
			else
				ledStatus = "OFF"
			end
			ctrl_module.LedControl( "wifi", ledStatus )
		else
			ctrl_module.LedControl( "wifi", "BLINK" )
		end
	end

	--Streaming checking
	local status = checker.CheckStreaming()
	local ledStatus
	if status == "OFF" then
		ledStatus = "OFF"
	elseif status == "CONNECTING" then
		ledStatus = "BLINK"
	elseif status == "CONNECTED" then
		ledStatus = "ON"
	elseif status == "PUSHING" then
		ledStatus = "ON"
	elseif status == "STOPPED" then
		ledStatus = "BLINK"
	else
		ledStatus = "ON"
	end
	ctrl_module.LedControl( "stream", ledStatus )

end

-----------

return _M
