local arp = {}
local config = require "arp_config"
local cfglink = require "link_config"

_G.arp_config = config.Load()
_G.link_config = cfglink.Load()

function arp.Init()

end

function arp.GetList()
    return _G.arp_config
end

function arp.DeleteOne(ip)
    _G.arp_config[ip] = nil
    _G.arp_config:__TRIGGER(true)
    return true
end

function arp.AddOne(ip, mac)
    if type(ip) ~= "string" or type(mac) ~= "string" then
        return false, "参数类型有误！"
    end

    if #mac > 17 or #ip > 15 then
        return false, "非法的参数长度！"
    end

    if not ip:match("%d+%.%d+%.%d+%.%d+") then
        return false, "无效的ip地址！"
    end

    if not mac:match("%w%w:%w%w:%w%w:%w%w:%w%w:%w%w") then
        return false, "无效的mac地址！"
    end

    for i=1, #mac do
        if mac:sub(i, i) ~= ":" and not tonumber(mac:sub(i, i), 16) then
            return false, "无效的mac字符！"
        end
    end

    if _G.arp_config[ip] then
        return false, "重复的ip地址！"
    end

    _G.arp_config[ip] = mac
    _G.arp_config:__TRIGGER(true)
    return true
end

function arp.SetNetLink(addr, port, authcode, timeout)
    if not addr or not port or not authcode or not timeout then
        return false, "Invalid arguments"
    end

    if type(addr) ~= "string" or not addr:match("%d+%.%d+%.%d+%.%d+") then
        return false, "Invalid addr"
    end

    port = tonumber(port)
    if not port or port < 1024 then
        return false, "Invalid port"
    end

    timeout = tonumber(timeout)
    if not timeout or timeout < 0 then
        return false, "Invalid timeout"
    end

    _G.link_config.addr = addr
    _G.link_config.port = port
    _G.link_config.authcode = authcode
    _G.link_config.timeout = timeout

    _G.link_config:__TRIGGER(true)
    return true
end

function arp.GetNetLink()
    return _G.link_config
end

return arp