local coaf = require "coaf.core"
local _dbg = require "coaf.debug"
local dhcp_service = require "dhcp_service"

local _M = {
	already_configured = nil,
	dont_too_fast_count = 0
}

-- The the first line from a specified file.
local function file_line( filename )
	local f = io.open( filename, "r" )
	if f then
		local r = f:read("*l")
		f:close()
		return r
	else
		return nil
	end
end

local function check_rndis_interface()
	--local item
	local lfs = require "lfs"
	for item in lfs.dir("/sys/class/net") do
		if item:match("usb%d+") then
			local f = io.popen("/usr/bin/readlink -f /sys/class/net/" .. item, "r" )
			if f then
				local path = f:read("*l")
				f:close()
				if path and path:match(".*/.*%.udc/gadget/.*") then
					return item
				end
			end
		end
	end
	return nil
end


function _M.Check()
	if _M.dont_too_fast_count == 0 then
		local rndis_if = check_rndis_interface()
		if rndis_if ~= _M.already_configured then
			if _M.already_configured then
				dhcp_service.StopDHCPService(_M.already_configured)
				os.execute("/sbin/ifconfig " .. _M.already_configured .. " down")
			end

			if rndis_if then
				os.execute("/sbin/ifconfig " .. rndis_if .. " 10.10.10.10 netmask 255.255.255.0 up")
				dhcp_service.StartDHCPService(rndis_if, "10.10.10.10", 24, {
					dynamic_start = "10.10.10.100",
					dynamic_end = "10.10.10.254"
				})
			end
			
			_M.already_configured = rndis_if
		end
	end

	_M.dont_too_fast_count = _M.dont_too_fast_count + 1
	if _M.dont_too_fast_count > 2 then
		_M.dont_too_fast_count = 0
	end
end

return _M